/* TiffSupport.c generated by valac 0.40.4, the Vala compiler
 * generated from TiffSupport.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define TYPE_PHOTO_FILE_FORMAT_DRIVER (photo_file_format_driver_get_type ())
#define PHOTO_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriver))
#define PHOTO_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriverClass))
#define IS_PHOTO_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER))
#define IS_PHOTO_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_DRIVER))
#define PHOTO_FILE_FORMAT_DRIVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_DRIVER, PhotoFileFormatDriverClass))

typedef struct _PhotoFileFormatDriver PhotoFileFormatDriver;
typedef struct _PhotoFileFormatDriverClass PhotoFileFormatDriverClass;
typedef struct _PhotoFileFormatDriverPrivate PhotoFileFormatDriverPrivate;

#define TYPE_PHOTO_FILE_FORMAT_PROPERTIES (photo_file_format_properties_get_type ())
#define PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties))
#define PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define PHOTO_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))

typedef struct _PhotoFileFormatProperties PhotoFileFormatProperties;
typedef struct _PhotoFileFormatPropertiesClass PhotoFileFormatPropertiesClass;

#define TYPE_PHOTO_FILE_ADAPTER (photo_file_adapter_get_type ())
#define PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter))
#define PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))
#define IS_PHOTO_FILE_ADAPTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_ADAPTER))
#define IS_PHOTO_FILE_ADAPTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_ADAPTER))
#define PHOTO_FILE_ADAPTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapterClass))

typedef struct _PhotoFileAdapter PhotoFileAdapter;
typedef struct _PhotoFileAdapterClass PhotoFileAdapterClass;

#define TYPE_PHOTO_FILE_READER (photo_file_reader_get_type ())
#define PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReader))
#define PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))
#define IS_PHOTO_FILE_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_READER))
#define IS_PHOTO_FILE_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_READER))
#define PHOTO_FILE_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_READER, PhotoFileReaderClass))

typedef struct _PhotoFileReader PhotoFileReader;
typedef struct _PhotoFileReaderClass PhotoFileReaderClass;

#define TYPE_MEDIA_METADATA (media_metadata_get_type ())
#define MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_METADATA, MediaMetadata))
#define MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_METADATA, MediaMetadataClass))
#define IS_MEDIA_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_METADATA))
#define IS_MEDIA_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_METADATA))
#define MEDIA_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_METADATA, MediaMetadataClass))

typedef struct _MediaMetadata MediaMetadata;
typedef struct _MediaMetadataClass MediaMetadataClass;

#define TYPE_PHOTO_METADATA (photo_metadata_get_type ())
#define PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_METADATA, PhotoMetadata))
#define PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_METADATA, PhotoMetadataClass))
#define IS_PHOTO_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_METADATA))
#define IS_PHOTO_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_METADATA))
#define PHOTO_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_METADATA, PhotoMetadataClass))

typedef struct _PhotoMetadata PhotoMetadata;
typedef struct _PhotoMetadataClass PhotoMetadataClass;

#define TYPE_PHOTO_FILE_WRITER (photo_file_writer_get_type ())
#define PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriter))
#define PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))
#define IS_PHOTO_FILE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_WRITER))
#define IS_PHOTO_FILE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_WRITER))
#define PHOTO_FILE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_WRITER, PhotoFileWriterClass))

typedef struct _PhotoFileWriter PhotoFileWriter;
typedef struct _PhotoFileWriterClass PhotoFileWriterClass;

#define TYPE_PHOTO_FILE_METADATA_WRITER (photo_file_metadata_writer_get_type ())
#define PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter))
#define PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))
#define IS_PHOTO_FILE_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_METADATA_WRITER))
#define IS_PHOTO_FILE_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_METADATA_WRITER))
#define PHOTO_FILE_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriterClass))

typedef struct _PhotoFileMetadataWriter PhotoFileMetadataWriter;
typedef struct _PhotoFileMetadataWriterClass PhotoFileMetadataWriterClass;

#define PHOTO_FILE_SNIFFER_TYPE_OPTIONS (photo_file_sniffer_options_get_type ())

#define TYPE_PHOTO_FILE_SNIFFER (photo_file_sniffer_get_type ())
#define PHOTO_FILE_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer))
#define PHOTO_FILE_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSnifferClass))
#define IS_PHOTO_FILE_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_SNIFFER))
#define IS_PHOTO_FILE_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_SNIFFER))
#define PHOTO_FILE_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSnifferClass))

typedef struct _PhotoFileSniffer PhotoFileSniffer;
typedef struct _PhotoFileSnifferClass PhotoFileSnifferClass;

#define PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER (photos_tiff_file_format_driver_get_type ())
#define PHOTOS_TIFF_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver))
#define PHOTOS_TIFF_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriverClass))
#define PHOTOS_IS_TIFF_FILE_FORMAT_DRIVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER))
#define PHOTOS_IS_TIFF_FILE_FORMAT_DRIVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER))
#define PHOTOS_TIFF_FILE_FORMAT_DRIVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriverClass))

typedef struct _PhotosTiffFileFormatDriver PhotosTiffFileFormatDriver;
typedef struct _PhotosTiffFileFormatDriverClass PhotosTiffFileFormatDriverClass;
typedef struct _PhotosTiffFileFormatDriverPrivate PhotosTiffFileFormatDriverPrivate;
#define _photo_file_format_driver_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_driver_unref (var), NULL)))

#define PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES (photos_tiff_file_format_properties_get_type ())
#define PHOTOS_TIFF_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties))
#define PHOTOS_TIFF_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatPropertiesClass))
#define PHOTOS_IS_TIFF_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES))
#define PHOTOS_IS_TIFF_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES))
#define PHOTOS_TIFF_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatPropertiesClass))

typedef struct _PhotosTiffFileFormatProperties PhotosTiffFileFormatProperties;
typedef struct _PhotosTiffFileFormatPropertiesClass PhotosTiffFileFormatPropertiesClass;

#define TYPE_GDK_READER (gdk_reader_get_type ())
#define GDK_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDK_READER, GdkReader))
#define GDK_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDK_READER, GdkReaderClass))
#define IS_GDK_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDK_READER))
#define IS_GDK_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDK_READER))
#define GDK_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDK_READER, GdkReaderClass))

typedef struct _GdkReader GdkReader;
typedef struct _GdkReaderClass GdkReaderClass;

#define PHOTOS_TYPE_TIFF_READER (photos_tiff_reader_get_type ())
#define PHOTOS_TIFF_READER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_TIFF_READER, PhotosTiffReader))
#define PHOTOS_TIFF_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_TIFF_READER, PhotosTiffReaderClass))
#define PHOTOS_IS_TIFF_READER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_TIFF_READER))
#define PHOTOS_IS_TIFF_READER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_TIFF_READER))
#define PHOTOS_TIFF_READER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_TIFF_READER, PhotosTiffReaderClass))

typedef struct _PhotosTiffReader PhotosTiffReader;
typedef struct _PhotosTiffReaderClass PhotosTiffReaderClass;

#define PHOTOS_TYPE_TIFF_WRITER (photos_tiff_writer_get_type ())
#define PHOTOS_TIFF_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_TIFF_WRITER, PhotosTiffWriter))
#define PHOTOS_TIFF_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_TIFF_WRITER, PhotosTiffWriterClass))
#define PHOTOS_IS_TIFF_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_TIFF_WRITER))
#define PHOTOS_IS_TIFF_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_TIFF_WRITER))
#define PHOTOS_TIFF_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_TIFF_WRITER, PhotosTiffWriterClass))

typedef struct _PhotosTiffWriter PhotosTiffWriter;
typedef struct _PhotosTiffWriterClass PhotosTiffWriterClass;

#define PHOTOS_TYPE_TIFF_METADATA_WRITER (photos_tiff_metadata_writer_get_type ())
#define PHOTOS_TIFF_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_TIFF_METADATA_WRITER, PhotosTiffMetadataWriter))
#define PHOTOS_TIFF_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_TIFF_METADATA_WRITER, PhotosTiffMetadataWriterClass))
#define PHOTOS_IS_TIFF_METADATA_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_TIFF_METADATA_WRITER))
#define PHOTOS_IS_TIFF_METADATA_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_TIFF_METADATA_WRITER))
#define PHOTOS_TIFF_METADATA_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_TIFF_METADATA_WRITER, PhotosTiffMetadataWriterClass))

typedef struct _PhotosTiffMetadataWriter PhotosTiffMetadataWriter;
typedef struct _PhotosTiffMetadataWriterClass PhotosTiffMetadataWriterClass;

#define TYPE_GDK_SNIFFER (gdk_sniffer_get_type ())
#define GDK_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDK_SNIFFER, GdkSniffer))
#define GDK_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDK_SNIFFER, GdkSnifferClass))
#define IS_GDK_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDK_SNIFFER))
#define IS_GDK_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDK_SNIFFER))
#define GDK_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDK_SNIFFER, GdkSnifferClass))

typedef struct _GdkSniffer GdkSniffer;
typedef struct _GdkSnifferClass GdkSnifferClass;

#define PHOTOS_TYPE_TIFF_SNIFFER (photos_tiff_sniffer_get_type ())
#define PHOTOS_TIFF_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PHOTOS_TYPE_TIFF_SNIFFER, PhotosTiffSniffer))
#define PHOTOS_TIFF_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PHOTOS_TYPE_TIFF_SNIFFER, PhotosTiffSnifferClass))
#define PHOTOS_IS_TIFF_SNIFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PHOTOS_TYPE_TIFF_SNIFFER))
#define PHOTOS_IS_TIFF_SNIFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PHOTOS_TYPE_TIFF_SNIFFER))
#define PHOTOS_TIFF_SNIFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PHOTOS_TYPE_TIFF_SNIFFER, PhotosTiffSnifferClass))

typedef struct _PhotosTiffSniffer PhotosTiffSniffer;
typedef struct _PhotosTiffSnifferClass PhotosTiffSnifferClass;
typedef struct _PhotoFileFormatPropertiesPrivate PhotoFileFormatPropertiesPrivate;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_PHOTO_FILE_FORMAT_FLAGS (photo_file_format_flags_get_type ())
typedef struct _PhotosTiffFileFormatPropertiesPrivate PhotosTiffFileFormatPropertiesPrivate;
#define _photo_file_format_properties_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_properties_unref (var), NULL)))
typedef struct _PhotoFileSnifferPrivate PhotoFileSnifferPrivate;

#define TYPE_DETECTED_PHOTO_INFORMATION (detected_photo_information_get_type ())
#define DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformation))
#define DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))
#define IS_DETECTED_PHOTO_INFORMATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DETECTED_PHOTO_INFORMATION))
#define IS_DETECTED_PHOTO_INFORMATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DETECTED_PHOTO_INFORMATION))
#define DETECTED_PHOTO_INFORMATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DETECTED_PHOTO_INFORMATION, DetectedPhotoInformationClass))

typedef struct _DetectedPhotoInformation DetectedPhotoInformation;
typedef struct _DetectedPhotoInformationClass DetectedPhotoInformationClass;
typedef struct _GdkSnifferPrivate GdkSnifferPrivate;
typedef struct _PhotosTiffSnifferPrivate PhotosTiffSnifferPrivate;
#define _detected_photo_information_unref0(var) ((var == NULL) ? NULL : (var = (detected_photo_information_unref (var), NULL)))
typedef struct _DetectedPhotoInformationPrivate DetectedPhotoInformationPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;
typedef struct _PhotoFileAdapterPrivate PhotoFileAdapterPrivate;
typedef struct _PhotoFileReaderPrivate PhotoFileReaderPrivate;
typedef struct _GdkReaderPrivate GdkReaderPrivate;
typedef struct _PhotosTiffReaderPrivate PhotosTiffReaderPrivate;
typedef struct _PhotoFileWriterPrivate PhotoFileWriterPrivate;

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())
typedef struct _PhotosTiffWriterPrivate PhotosTiffWriterPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _PhotoFileMetadataWriterPrivate PhotoFileMetadataWriterPrivate;
typedef struct _PhotosTiffMetadataWriterPrivate PhotosTiffMetadataWriterPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

typedef enum  {
	PHOTO_FILE_SNIFFER_OPTIONS_GET_ALL = 0x00000000,
	PHOTO_FILE_SNIFFER_OPTIONS_NO_MD5 = 0x00000001
} PhotoFileSnifferOptions;

struct _PhotoFileFormatDriver {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileFormatDriverPrivate * priv;
};

struct _PhotoFileFormatDriverClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileFormatDriver *self);
	PhotoFileFormatProperties* (*get_properties) (PhotoFileFormatDriver* self);
	PhotoFileReader* (*create_reader) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoMetadata* (*create_metadata) (PhotoFileFormatDriver* self);
	gboolean (*can_write_image) (PhotoFileFormatDriver* self);
	gboolean (*can_write_metadata) (PhotoFileFormatDriver* self);
	PhotoFileWriter* (*create_writer) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoFileMetadataWriter* (*create_metadata_writer) (PhotoFileFormatDriver* self, const gchar* filepath);
	PhotoFileSniffer* (*create_sniffer) (PhotoFileFormatDriver* self, GFile* file, PhotoFileSnifferOptions options);
};

struct _PhotosTiffFileFormatDriver {
	PhotoFileFormatDriver parent_instance;
	PhotosTiffFileFormatDriverPrivate * priv;
};

struct _PhotosTiffFileFormatDriverClass {
	PhotoFileFormatDriverClass parent_class;
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

typedef enum  {
	PHOTO_FILE_FORMAT_FLAGS_NONE = 0x00000000
} PhotoFileFormatFlags;

struct _PhotoFileFormatProperties {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileFormatPropertiesPrivate * priv;
};

struct _PhotoFileFormatPropertiesClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileFormatProperties *self);
	PhotoFileFormat (*get_file_format) (PhotoFileFormatProperties* self);
	PhotoFileFormatFlags (*get_flags) (PhotoFileFormatProperties* self);
	gboolean (*is_recognized_extension) (PhotoFileFormatProperties* self, const gchar* ext);
	gchar* (*get_default_extension) (PhotoFileFormatProperties* self);
	gchar** (*get_known_extensions) (PhotoFileFormatProperties* self, int* result_length1);
	gchar* (*get_default_mime_type) (PhotoFileFormatProperties* self);
	gchar** (*get_mime_types) (PhotoFileFormatProperties* self, int* result_length1);
	gchar* (*get_user_visible_name) (PhotoFileFormatProperties* self);
};

struct _PhotosTiffFileFormatProperties {
	PhotoFileFormatProperties parent_instance;
	PhotosTiffFileFormatPropertiesPrivate * priv;
};

struct _PhotosTiffFileFormatPropertiesClass {
	PhotoFileFormatPropertiesClass parent_class;
};

struct _PhotoFileSniffer {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileSnifferPrivate * priv;
	GFile* file;
	PhotoFileSnifferOptions options;
	gboolean calc_md5;
};

struct _PhotoFileSnifferClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileSniffer *self);
	DetectedPhotoInformation* (*sniff) (PhotoFileSniffer* self, gboolean* is_corrupted, GError** error);
};

struct _GdkSniffer {
	PhotoFileSniffer parent_instance;
	GdkSnifferPrivate * priv;
};

struct _GdkSnifferClass {
	PhotoFileSnifferClass parent_class;
};

struct _PhotosTiffSniffer {
	GdkSniffer parent_instance;
	PhotosTiffSnifferPrivate * priv;
};

struct _PhotosTiffSnifferClass {
	GdkSnifferClass parent_class;
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _DetectedPhotoInformation {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DetectedPhotoInformationPrivate * priv;
	PhotoFileFormat file_format;
	PhotoMetadata* metadata;
	gchar* md5;
	gchar* exif_md5;
	gchar* thumbnail_md5;
	gchar* format_name;
	Dimensions image_dim;
	GdkColorspace colorspace;
	gint channels;
	gint bits_per_channel;
};

struct _DetectedPhotoInformationClass {
	GTypeClass parent_class;
	void (*finalize) (DetectedPhotoInformation *self);
};

struct _PhotoFileAdapter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoFileAdapterPrivate * priv;
};

struct _PhotoFileAdapterClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoFileAdapter *self);
};

struct _PhotoFileReader {
	PhotoFileAdapter parent_instance;
	PhotoFileReaderPrivate * priv;
};

struct _PhotoFileReaderClass {
	PhotoFileAdapterClass parent_class;
	PhotoMetadata* (*read_metadata) (PhotoFileReader* self, GError** error);
	GdkPixbuf* (*unscaled_read) (PhotoFileReader* self, GError** error);
	GdkPixbuf* (*scaled_read) (PhotoFileReader* self, Dimensions* full, Dimensions* scaled, GError** error);
};

struct _GdkReader {
	PhotoFileReader parent_instance;
	GdkReaderPrivate * priv;
};

struct _GdkReaderClass {
	PhotoFileReaderClass parent_class;
};

struct _PhotosTiffReader {
	GdkReader parent_instance;
	PhotosTiffReaderPrivate * priv;
};

struct _PhotosTiffReaderClass {
	GdkReaderClass parent_class;
};

typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

struct _PhotoFileWriter {
	PhotoFileAdapter parent_instance;
	PhotoFileWriterPrivate * priv;
};

struct _PhotoFileWriterClass {
	PhotoFileAdapterClass parent_class;
	void (*write) (PhotoFileWriter* self, GdkPixbuf* pixbuf, JpegQuality quality, GError** error);
};

struct _PhotosTiffWriter {
	PhotoFileWriter parent_instance;
	PhotosTiffWriterPrivate * priv;
};

struct _PhotosTiffWriterClass {
	PhotoFileWriterClass parent_class;
};

struct _PhotoFileMetadataWriter {
	PhotoFileAdapter parent_instance;
	PhotoFileMetadataWriterPrivate * priv;
};

struct _PhotoFileMetadataWriterClass {
	PhotoFileAdapterClass parent_class;
	void (*write_metadata) (PhotoFileMetadataWriter* self, PhotoMetadata* metadata, GError** error);
};

struct _PhotosTiffMetadataWriter {
	PhotoFileMetadataWriter parent_instance;
	PhotosTiffMetadataWriterPrivate * priv;
};

struct _PhotosTiffMetadataWriterClass {
	PhotoFileMetadataWriterClass parent_class;
};


static gpointer photos_tiff_file_format_driver_parent_class = NULL;
static PhotosTiffFileFormatDriver* photos_tiff_file_format_driver_instance;
static PhotosTiffFileFormatDriver* photos_tiff_file_format_driver_instance = NULL;
static gpointer photos_tiff_file_format_properties_parent_class = NULL;
static gchar** photos_tiff_file_format_properties_KNOWN_EXTENSIONS;
static gint photos_tiff_file_format_properties_KNOWN_EXTENSIONS_length1;
static gchar** photos_tiff_file_format_properties_KNOWN_EXTENSIONS = NULL;
static gint photos_tiff_file_format_properties_KNOWN_EXTENSIONS_length1 = 0;
static gint _photos_tiff_file_format_properties_KNOWN_EXTENSIONS_size_ = 0;
static gchar** photos_tiff_file_format_properties_KNOWN_MIME_TYPES;
static gint photos_tiff_file_format_properties_KNOWN_MIME_TYPES_length1;
static gchar** photos_tiff_file_format_properties_KNOWN_MIME_TYPES = NULL;
static gint photos_tiff_file_format_properties_KNOWN_MIME_TYPES_length1 = 0;
static gint _photos_tiff_file_format_properties_KNOWN_MIME_TYPES_size_ = 0;
static PhotosTiffFileFormatProperties* photos_tiff_file_format_properties_instance;
static PhotosTiffFileFormatProperties* photos_tiff_file_format_properties_instance = NULL;
static gpointer photos_tiff_sniffer_parent_class = NULL;
static gpointer photos_tiff_reader_parent_class = NULL;
static gpointer photos_tiff_writer_parent_class = NULL;
static gpointer photos_tiff_metadata_writer_parent_class = NULL;

gpointer photo_file_format_driver_ref (gpointer instance);
void photo_file_format_driver_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_driver (const gchar* name,
                                                 const gchar* nick,
                                                 const gchar* blurb,
                                                 GType object_type,
                                                 GParamFlags flags);
void value_set_photo_file_format_driver (GValue* value,
                                         gpointer v_object);
void value_take_photo_file_format_driver (GValue* value,
                                          gpointer v_object);
gpointer value_get_photo_file_format_driver (const GValue* value);
GType photo_file_format_driver_get_type (void) G_GNUC_CONST;
gpointer photo_file_format_properties_ref (gpointer instance);
void photo_file_format_properties_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_properties (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
void value_set_photo_file_format_properties (GValue* value,
                                             gpointer v_object);
void value_take_photo_file_format_properties (GValue* value,
                                              gpointer v_object);
gpointer value_get_photo_file_format_properties (const GValue* value);
GType photo_file_format_properties_get_type (void) G_GNUC_CONST;
gpointer photo_file_adapter_ref (gpointer instance);
void photo_file_adapter_unref (gpointer instance);
GParamSpec* param_spec_photo_file_adapter (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
void value_set_photo_file_adapter (GValue* value,
                                   gpointer v_object);
void value_take_photo_file_adapter (GValue* value,
                                    gpointer v_object);
gpointer value_get_photo_file_adapter (const GValue* value);
GType photo_file_adapter_get_type (void) G_GNUC_CONST;
GType photo_file_reader_get_type (void) G_GNUC_CONST;
gpointer media_metadata_ref (gpointer instance);
void media_metadata_unref (gpointer instance);
GParamSpec* param_spec_media_metadata (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
void value_set_media_metadata (GValue* value,
                               gpointer v_object);
void value_take_media_metadata (GValue* value,
                                gpointer v_object);
gpointer value_get_media_metadata (const GValue* value);
GType media_metadata_get_type (void) G_GNUC_CONST;
GType photo_metadata_get_type (void) G_GNUC_CONST;
GType photo_file_writer_get_type (void) G_GNUC_CONST;
GType photo_file_metadata_writer_get_type (void) G_GNUC_CONST;
GType photo_file_sniffer_options_get_type (void) G_GNUC_CONST;
gpointer photo_file_sniffer_ref (gpointer instance);
void photo_file_sniffer_unref (gpointer instance);
GParamSpec* param_spec_photo_file_sniffer (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
void value_set_photo_file_sniffer (GValue* value,
                                   gpointer v_object);
void value_take_photo_file_sniffer (GValue* value,
                                    gpointer v_object);
gpointer value_get_photo_file_sniffer (const GValue* value);
GType photo_file_sniffer_get_type (void) G_GNUC_CONST;
GType photos_tiff_file_format_driver_get_type (void) G_GNUC_CONST;
void photos_tiff_file_format_driver_init (void);
PhotosTiffFileFormatDriver* photos_tiff_file_format_driver_new (void);
PhotosTiffFileFormatDriver* photos_tiff_file_format_driver_construct (GType object_type);
void photos_tiff_file_format_properties_init (void);
PhotosTiffFileFormatDriver* photos_tiff_file_format_driver_get_instance (void);
static PhotoFileFormatProperties* photos_tiff_file_format_driver_real_get_properties (PhotoFileFormatDriver* base);
GType photos_tiff_file_format_properties_get_type (void) G_GNUC_CONST;
PhotosTiffFileFormatProperties* photos_tiff_file_format_properties_get_instance (void);
static PhotoFileReader* photos_tiff_file_format_driver_real_create_reader (PhotoFileFormatDriver* base,
                                                                    const gchar* filepath);
PhotosTiffReader* photos_tiff_reader_new (const gchar* filepath);
PhotosTiffReader* photos_tiff_reader_construct (GType object_type,
                                                const gchar* filepath);
GType gdk_reader_get_type (void) G_GNUC_CONST;
GType photos_tiff_reader_get_type (void) G_GNUC_CONST;
static PhotoMetadata* photos_tiff_file_format_driver_real_create_metadata (PhotoFileFormatDriver* base);
PhotoMetadata* photo_metadata_new (void);
PhotoMetadata* photo_metadata_construct (GType object_type);
static gboolean photos_tiff_file_format_driver_real_can_write_image (PhotoFileFormatDriver* base);
static gboolean photos_tiff_file_format_driver_real_can_write_metadata (PhotoFileFormatDriver* base);
static PhotoFileWriter* photos_tiff_file_format_driver_real_create_writer (PhotoFileFormatDriver* base,
                                                                    const gchar* filepath);
PhotosTiffWriter* photos_tiff_writer_new (const gchar* filepath);
PhotosTiffWriter* photos_tiff_writer_construct (GType object_type,
                                                const gchar* filepath);
GType photos_tiff_writer_get_type (void) G_GNUC_CONST;
static PhotoFileMetadataWriter* photos_tiff_file_format_driver_real_create_metadata_writer (PhotoFileFormatDriver* base,
                                                                                     const gchar* filepath);
PhotosTiffMetadataWriter* photos_tiff_metadata_writer_new (const gchar* filepath);
PhotosTiffMetadataWriter* photos_tiff_metadata_writer_construct (GType object_type,
                                                                 const gchar* filepath);
GType photos_tiff_metadata_writer_get_type (void) G_GNUC_CONST;
static PhotoFileSniffer* photos_tiff_file_format_driver_real_create_sniffer (PhotoFileFormatDriver* base,
                                                                      GFile* file,
                                                                      PhotoFileSnifferOptions options);
PhotosTiffSniffer* photos_tiff_sniffer_new (GFile* file,
                                            PhotoFileSnifferOptions options);
PhotosTiffSniffer* photos_tiff_sniffer_construct (GType object_type,
                                                  GFile* file,
                                                  PhotoFileSnifferOptions options);
GType gdk_sniffer_get_type (void) G_GNUC_CONST;
GType photos_tiff_sniffer_get_type (void) G_GNUC_CONST;
PhotoFileFormatDriver* photo_file_format_driver_construct (GType object_type);
static void photos_tiff_file_format_driver_finalize (PhotoFileFormatDriver * obj);
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType photo_file_format_flags_get_type (void) G_GNUC_CONST;
PhotosTiffFileFormatProperties* photos_tiff_file_format_properties_new (void);
PhotosTiffFileFormatProperties* photos_tiff_file_format_properties_construct (GType object_type);
static PhotoFileFormat photos_tiff_file_format_properties_real_get_file_format (PhotoFileFormatProperties* base);
static PhotoFileFormatFlags photos_tiff_file_format_properties_real_get_flags (PhotoFileFormatProperties* base);
static gchar* photos_tiff_file_format_properties_real_get_default_extension (PhotoFileFormatProperties* base);
static gchar* photos_tiff_file_format_properties_real_get_user_visible_name (PhotoFileFormatProperties* base);
static gchar** photos_tiff_file_format_properties_real_get_known_extensions (PhotoFileFormatProperties* base,
                                                                      int* result_length1);
static gchar** _vala_array_dup14 (gchar** self,
                           int length);
static gchar* photos_tiff_file_format_properties_real_get_default_mime_type (PhotoFileFormatProperties* base);
static gchar** photos_tiff_file_format_properties_real_get_mime_types (PhotoFileFormatProperties* base,
                                                                int* result_length1);
static gchar** _vala_array_dup15 (gchar** self,
                           int length);
PhotoFileFormatProperties* photo_file_format_properties_construct (GType object_type);
static void photos_tiff_file_format_properties_finalize (PhotoFileFormatProperties * obj);
gpointer detected_photo_information_ref (gpointer instance);
void detected_photo_information_unref (gpointer instance);
GParamSpec* param_spec_detected_photo_information (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
void value_set_detected_photo_information (GValue* value,
                                           gpointer v_object);
void value_take_detected_photo_information (GValue* value,
                                            gpointer v_object);
gpointer value_get_detected_photo_information (const GValue* value);
GType detected_photo_information_get_type (void) G_GNUC_CONST;
GdkSniffer* gdk_sniffer_construct (GType object_type,
                                   GFile* file,
                                   PhotoFileSnifferOptions options);
static DetectedPhotoInformation* photos_tiff_sniffer_real_sniff (PhotoFileSniffer* base,
                                                          gboolean* is_corrupted,
                                                          GError** error);
gboolean photos_is_tiff (GFile* file,
                         GCancellable* cancellable,
                         GError** error);
DetectedPhotoInformation* photo_file_sniffer_sniff (PhotoFileSniffer* self,
                                                    gboolean* is_corrupted,
                                                    GError** error);
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
GdkReader* gdk_reader_construct (GType object_type,
                                 const gchar* filepath,
                                 PhotoFileFormat file_format);
GType jpeg_quality_get_type (void) G_GNUC_CONST;
#define PHOTOS_TIFF_WRITER_COMPRESSION_NONE "1"
#define PHOTOS_TIFF_WRITER_COMPRESSION_HUFFMAN "2"
#define PHOTOS_TIFF_WRITER_COMPRESSION_LZW "5"
#define PHOTOS_TIFF_WRITER_COMPRESSION_JPEG "7"
#define PHOTOS_TIFF_WRITER_COMPRESSION_DEFLATE "8"
PhotoFileWriter* photo_file_writer_construct (GType object_type,
                                              const gchar* filepath,
                                              PhotoFileFormat file_format);
static void photos_tiff_writer_real_write (PhotoFileWriter* base,
                                    GdkPixbuf* pixbuf,
                                    JpegQuality quality,
                                    GError** error);
gchar* photo_file_adapter_get_filepath (PhotoFileAdapter* self);
PhotoFileMetadataWriter* photo_file_metadata_writer_construct (GType object_type,
                                                               const gchar* filepath,
                                                               PhotoFileFormat file_format);
static void photos_tiff_metadata_writer_real_write_metadata (PhotoFileMetadataWriter* base,
                                                      PhotoMetadata* metadata,
                                                      GError** error);
void photo_metadata_write_to_file (PhotoMetadata* self,
                                   GFile* file,
                                   GError** error);
GFile* photo_file_adapter_get_file (PhotoFileAdapter* self);


void
photos_tiff_file_format_driver_init (void)
{
	PhotosTiffFileFormatDriver* _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_driver_new ();
#line 13 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_photo_file_format_driver_unref0 (photos_tiff_file_format_driver_instance);
#line 13 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_driver_instance = _tmp0_;
#line 14 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_init ();
#line 677 "TiffSupport.c"
}


static gpointer
_photo_file_format_driver_ref0 (gpointer self)
{
#line 18 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self ? photo_file_format_driver_ref (self) : NULL;
#line 686 "TiffSupport.c"
}


PhotosTiffFileFormatDriver*
photos_tiff_file_format_driver_get_instance (void)
{
	PhotosTiffFileFormatDriver* result = NULL;
	PhotosTiffFileFormatDriver* _tmp0_;
	PhotosTiffFileFormatDriver* _tmp1_;
#line 18 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_driver_instance;
#line 18 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = _photo_file_format_driver_ref0 (_tmp0_);
#line 18 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp1_;
#line 18 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 704 "TiffSupport.c"
}


static PhotoFileFormatProperties*
photos_tiff_file_format_driver_real_get_properties (PhotoFileFormatDriver* base)
{
	PhotosTiffFileFormatDriver * self;
	PhotoFileFormatProperties* result = NULL;
	PhotosTiffFileFormatProperties* _tmp0_;
#line 21 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 22 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_properties_get_instance ();
#line 22 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties);
#line 22 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 722 "TiffSupport.c"
}


static PhotoFileReader*
photos_tiff_file_format_driver_real_create_reader (PhotoFileFormatDriver* base,
                                                   const gchar* filepath)
{
	PhotosTiffFileFormatDriver * self;
	PhotoFileReader* result = NULL;
	PhotosTiffReader* _tmp0_;
#line 25 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 25 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 26 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_reader_new (filepath);
#line 26 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_READER, PhotoFileReader);
#line 26 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 743 "TiffSupport.c"
}


static PhotoMetadata*
photos_tiff_file_format_driver_real_create_metadata (PhotoFileFormatDriver* base)
{
	PhotosTiffFileFormatDriver * self;
	PhotoMetadata* result = NULL;
	PhotoMetadata* _tmp0_;
#line 29 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 30 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photo_metadata_new ();
#line 30 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp0_;
#line 30 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 761 "TiffSupport.c"
}


static gboolean
photos_tiff_file_format_driver_real_can_write_image (PhotoFileFormatDriver* base)
{
	PhotosTiffFileFormatDriver * self;
	gboolean result = FALSE;
#line 33 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 34 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = TRUE;
#line 34 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 776 "TiffSupport.c"
}


static gboolean
photos_tiff_file_format_driver_real_can_write_metadata (PhotoFileFormatDriver* base)
{
	PhotosTiffFileFormatDriver * self;
	gboolean result = FALSE;
#line 37 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 38 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = TRUE;
#line 38 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 791 "TiffSupport.c"
}


static PhotoFileWriter*
photos_tiff_file_format_driver_real_create_writer (PhotoFileFormatDriver* base,
                                                   const gchar* filepath)
{
	PhotosTiffFileFormatDriver * self;
	PhotoFileWriter* result = NULL;
	PhotosTiffWriter* _tmp0_;
#line 41 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 41 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 42 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_writer_new (filepath);
#line 42 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_WRITER, PhotoFileWriter);
#line 42 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 812 "TiffSupport.c"
}


static PhotoFileMetadataWriter*
photos_tiff_file_format_driver_real_create_metadata_writer (PhotoFileFormatDriver* base,
                                                            const gchar* filepath)
{
	PhotosTiffFileFormatDriver * self;
	PhotoFileMetadataWriter* result = NULL;
	PhotosTiffMetadataWriter* _tmp0_;
#line 45 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 45 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 46 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_metadata_writer_new (filepath);
#line 46 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_METADATA_WRITER, PhotoFileMetadataWriter);
#line 46 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 833 "TiffSupport.c"
}


static PhotoFileSniffer*
photos_tiff_file_format_driver_real_create_sniffer (PhotoFileFormatDriver* base,
                                                    GFile* file,
                                                    PhotoFileSnifferOptions options)
{
	PhotosTiffFileFormatDriver * self;
	PhotoFileSniffer* result = NULL;
	PhotosTiffSniffer* _tmp0_;
#line 49 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 49 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 50 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_sniffer_new (file, options);
#line 50 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer);
#line 50 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 855 "TiffSupport.c"
}


PhotosTiffFileFormatDriver*
photos_tiff_file_format_driver_construct (GType object_type)
{
	PhotosTiffFileFormatDriver* self = NULL;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = (PhotosTiffFileFormatDriver*) photo_file_format_driver_construct (object_type);
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self;
#line 867 "TiffSupport.c"
}


PhotosTiffFileFormatDriver*
photos_tiff_file_format_driver_new (void)
{
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return photos_tiff_file_format_driver_construct (PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER);
#line 876 "TiffSupport.c"
}


static void
photos_tiff_file_format_driver_class_init (PhotosTiffFileFormatDriverClass * klass)
{
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_driver_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->finalize = photos_tiff_file_format_driver_finalize;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->get_properties = (PhotoFileFormatProperties* (*) (PhotoFileFormatDriver *)) photos_tiff_file_format_driver_real_get_properties;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_reader = (PhotoFileReader* (*) (PhotoFileFormatDriver *, const gchar*)) photos_tiff_file_format_driver_real_create_reader;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_metadata = (PhotoMetadata* (*) (PhotoFileFormatDriver *)) photos_tiff_file_format_driver_real_create_metadata;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->can_write_image = (gboolean (*) (PhotoFileFormatDriver *)) photos_tiff_file_format_driver_real_can_write_image;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->can_write_metadata = (gboolean (*) (PhotoFileFormatDriver *)) photos_tiff_file_format_driver_real_can_write_metadata;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_writer = (PhotoFileWriter* (*) (PhotoFileFormatDriver *, const gchar*)) photos_tiff_file_format_driver_real_create_writer;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_metadata_writer = (PhotoFileMetadataWriter* (*) (PhotoFileFormatDriver *, const gchar*)) photos_tiff_file_format_driver_real_create_metadata_writer;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatDriverClass *) klass)->create_sniffer = (PhotoFileSniffer* (*) (PhotoFileFormatDriver *, GFile*, PhotoFileSnifferOptions)) photos_tiff_file_format_driver_real_create_sniffer;
#line 903 "TiffSupport.c"
}


static void
photos_tiff_file_format_driver_instance_init (PhotosTiffFileFormatDriver * self)
{
}


static void
photos_tiff_file_format_driver_finalize (PhotoFileFormatDriver * obj)
{
	PhotosTiffFileFormatDriver * self;
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTOS_TYPE_TIFF_FILE_FORMAT_DRIVER, PhotosTiffFileFormatDriver);
#line 9 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	PHOTO_FILE_FORMAT_DRIVER_CLASS (photos_tiff_file_format_driver_parent_class)->finalize (obj);
#line 921 "TiffSupport.c"
}


GType
photos_tiff_file_format_driver_get_type (void)
{
	static volatile gsize photos_tiff_file_format_driver_type_id__volatile = 0;
	if (g_once_init_enter (&photos_tiff_file_format_driver_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosTiffFileFormatDriverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_tiff_file_format_driver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosTiffFileFormatDriver), 0, (GInstanceInitFunc) photos_tiff_file_format_driver_instance_init, NULL };
		GType photos_tiff_file_format_driver_type_id;
		photos_tiff_file_format_driver_type_id = g_type_register_static (TYPE_PHOTO_FILE_FORMAT_DRIVER, "PhotosTiffFileFormatDriver", &g_define_type_info, 0);
		g_once_init_leave (&photos_tiff_file_format_driver_type_id__volatile, photos_tiff_file_format_driver_type_id);
	}
	return photos_tiff_file_format_driver_type_id__volatile;
}


void
photos_tiff_file_format_properties_init (void)
{
	PhotosTiffFileFormatProperties* _tmp0_;
#line 66 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_properties_new ();
#line 66 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_photo_file_format_properties_unref0 (photos_tiff_file_format_properties_instance);
#line 66 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_instance = _tmp0_;
#line 949 "TiffSupport.c"
}


static gpointer
_photo_file_format_properties_ref0 (gpointer self)
{
#line 70 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self ? photo_file_format_properties_ref (self) : NULL;
#line 958 "TiffSupport.c"
}


PhotosTiffFileFormatProperties*
photos_tiff_file_format_properties_get_instance (void)
{
	PhotosTiffFileFormatProperties* result = NULL;
	PhotosTiffFileFormatProperties* _tmp0_;
	PhotosTiffFileFormatProperties* _tmp1_;
#line 70 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_properties_instance;
#line 70 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = _photo_file_format_properties_ref0 (_tmp0_);
#line 70 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp1_;
#line 70 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 976 "TiffSupport.c"
}


static PhotoFileFormat
photos_tiff_file_format_properties_real_get_file_format (PhotoFileFormatProperties* base)
{
	PhotosTiffFileFormatProperties * self;
	PhotoFileFormat result = 0;
#line 73 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 74 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = PHOTO_FILE_FORMAT_TIFF;
#line 74 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 991 "TiffSupport.c"
}


static PhotoFileFormatFlags
photos_tiff_file_format_properties_real_get_flags (PhotoFileFormatProperties* base)
{
	PhotosTiffFileFormatProperties * self;
	PhotoFileFormatFlags result = 0;
#line 77 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 78 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = PHOTO_FILE_FORMAT_FLAGS_NONE;
#line 78 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1006 "TiffSupport.c"
}


static gchar*
photos_tiff_file_format_properties_real_get_default_extension (PhotoFileFormatProperties* base)
{
	PhotosTiffFileFormatProperties * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 81 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 82 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = g_strdup ("tif");
#line 82 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp0_;
#line 82 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1024 "TiffSupport.c"
}


static gchar*
photos_tiff_file_format_properties_real_get_user_visible_name (PhotoFileFormatProperties* base)
{
	PhotosTiffFileFormatProperties * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 85 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 86 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = g_strdup (_ ("TIFF"));
#line 86 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp0_;
#line 86 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1042 "TiffSupport.c"
}


static gchar**
_vala_array_dup14 (gchar** self,
                   int length)
{
	gchar** result;
	int i;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = g_new0 (gchar*, length + 1);
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	for (i = 0; i < length; i++) {
#line 1056 "TiffSupport.c"
		gchar* _tmp0_;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_tmp0_ = g_strdup (self[i]);
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		result[i] = _tmp0_;
#line 1062 "TiffSupport.c"
	}
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1066 "TiffSupport.c"
}


static gchar**
photos_tiff_file_format_properties_real_get_known_extensions (PhotoFileFormatProperties* base,
                                                              int* result_length1)
{
	PhotosTiffFileFormatProperties * self;
	gchar** result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar** _tmp2_;
	gint _tmp2__length1;
#line 89 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_properties_KNOWN_EXTENSIONS;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0__length1 = photos_tiff_file_format_properties_KNOWN_EXTENSIONS_length1;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup14 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1__length1 = _tmp0__length1;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2_ = _tmp1_;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2__length1 = _tmp1__length1;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (result_length1) {
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		*result_length1 = _tmp2__length1;
#line 1100 "TiffSupport.c"
	}
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp2_;
#line 90 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1106 "TiffSupport.c"
}


static gchar*
photos_tiff_file_format_properties_real_get_default_mime_type (PhotoFileFormatProperties* base)
{
	PhotosTiffFileFormatProperties * self;
	gchar* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 93 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 94 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_properties_KNOWN_MIME_TYPES;
#line 94 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0__length1 = photos_tiff_file_format_properties_KNOWN_MIME_TYPES_length1;
#line 94 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = _tmp0_[0];
#line 94 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 94 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp2_;
#line 94 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1133 "TiffSupport.c"
}


static gchar**
_vala_array_dup15 (gchar** self,
                   int length)
{
	gchar** result;
	int i;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = g_new0 (gchar*, length + 1);
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	for (i = 0; i < length; i++) {
#line 1147 "TiffSupport.c"
		gchar* _tmp0_;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_tmp0_ = g_strdup (self[i]);
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		result[i] = _tmp0_;
#line 1153 "TiffSupport.c"
	}
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1157 "TiffSupport.c"
}


static gchar**
photos_tiff_file_format_properties_real_get_mime_types (PhotoFileFormatProperties* base,
                                                        int* result_length1)
{
	PhotosTiffFileFormatProperties * self;
	gchar** result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar** _tmp2_;
	gint _tmp2__length1;
#line 97 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_tiff_file_format_properties_KNOWN_MIME_TYPES;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0__length1 = photos_tiff_file_format_properties_KNOWN_MIME_TYPES_length1;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup15 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1__length1 = _tmp0__length1;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2_ = _tmp1_;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2__length1 = _tmp1__length1;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (result_length1) {
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		*result_length1 = _tmp2__length1;
#line 1191 "TiffSupport.c"
	}
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp2_;
#line 98 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1197 "TiffSupport.c"
}


PhotosTiffFileFormatProperties*
photos_tiff_file_format_properties_construct (GType object_type)
{
	PhotosTiffFileFormatProperties* self = NULL;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = (PhotosTiffFileFormatProperties*) photo_file_format_properties_construct (object_type);
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self;
#line 1209 "TiffSupport.c"
}


PhotosTiffFileFormatProperties*
photos_tiff_file_format_properties_new (void)
{
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return photos_tiff_file_format_properties_construct (PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES);
#line 1218 "TiffSupport.c"
}


static void
photos_tiff_file_format_properties_class_init (PhotosTiffFileFormatPropertiesClass * klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_parent_class = g_type_class_peek_parent (klass);
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->finalize = photos_tiff_file_format_properties_finalize;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_file_format = (PhotoFileFormat (*) (PhotoFileFormatProperties *)) photos_tiff_file_format_properties_real_get_file_format;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_flags = (PhotoFileFormatFlags (*) (PhotoFileFormatProperties *)) photos_tiff_file_format_properties_real_get_flags;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_default_extension = (gchar* (*) (PhotoFileFormatProperties *)) photos_tiff_file_format_properties_real_get_default_extension;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_user_visible_name = (gchar* (*) (PhotoFileFormatProperties *)) photos_tiff_file_format_properties_real_get_user_visible_name;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_known_extensions = (gchar** (*) (PhotoFileFormatProperties *, int*)) photos_tiff_file_format_properties_real_get_known_extensions;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_default_mime_type = (gchar* (*) (PhotoFileFormatProperties *)) photos_tiff_file_format_properties_real_get_default_mime_type;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileFormatPropertiesClass *) klass)->get_mime_types = (gchar** (*) (PhotoFileFormatProperties *, int*)) photos_tiff_file_format_properties_real_get_mime_types;
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = g_strdup ("tif");
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = g_strdup ("tiff");
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2_[0] = _tmp0_;
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp2_[1] = _tmp1_;
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_KNOWN_EXTENSIONS = _tmp2_;
#line 55 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_KNOWN_EXTENSIONS_length1 = 2;
#line 59 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp3_ = g_strdup ("image/tiff");
#line 59 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp4_ = g_new0 (gchar*, 1 + 1);
#line 59 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp4_[0] = _tmp3_;
#line 59 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_KNOWN_MIME_TYPES = _tmp4_;
#line 59 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_file_format_properties_KNOWN_MIME_TYPES_length1 = 1;
#line 1272 "TiffSupport.c"
}


static void
photos_tiff_file_format_properties_instance_init (PhotosTiffFileFormatProperties * self)
{
}


static void
photos_tiff_file_format_properties_finalize (PhotoFileFormatProperties * obj)
{
	PhotosTiffFileFormatProperties * self;
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PHOTOS_TYPE_TIFF_FILE_FORMAT_PROPERTIES, PhotosTiffFileFormatProperties);
#line 54 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	PHOTO_FILE_FORMAT_PROPERTIES_CLASS (photos_tiff_file_format_properties_parent_class)->finalize (obj);
#line 1290 "TiffSupport.c"
}


GType
photos_tiff_file_format_properties_get_type (void)
{
	static volatile gsize photos_tiff_file_format_properties_type_id__volatile = 0;
	if (g_once_init_enter (&photos_tiff_file_format_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosTiffFileFormatPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_tiff_file_format_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosTiffFileFormatProperties), 0, (GInstanceInitFunc) photos_tiff_file_format_properties_instance_init, NULL };
		GType photos_tiff_file_format_properties_type_id;
		photos_tiff_file_format_properties_type_id = g_type_register_static (TYPE_PHOTO_FILE_FORMAT_PROPERTIES, "PhotosTiffFileFormatProperties", &g_define_type_info, 0);
		g_once_init_leave (&photos_tiff_file_format_properties_type_id__volatile, photos_tiff_file_format_properties_type_id);
	}
	return photos_tiff_file_format_properties_type_id__volatile;
}


PhotosTiffSniffer*
photos_tiff_sniffer_construct (GType object_type,
                               GFile* file,
                               PhotoFileSnifferOptions options)
{
	PhotosTiffSniffer* self = NULL;
#line 103 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), NULL);
#line 104 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = (PhotosTiffSniffer*) gdk_sniffer_construct (object_type, file, options);
#line 103 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self;
#line 1320 "TiffSupport.c"
}


PhotosTiffSniffer*
photos_tiff_sniffer_new (GFile* file,
                         PhotoFileSnifferOptions options)
{
#line 103 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return photos_tiff_sniffer_construct (PHOTOS_TYPE_TIFF_SNIFFER, file, options);
#line 1330 "TiffSupport.c"
}


static gpointer
_detected_photo_information_ref0 (gpointer self)
{
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self ? detected_photo_information_ref (self) : NULL;
#line 1339 "TiffSupport.c"
}


static DetectedPhotoInformation*
photos_tiff_sniffer_real_sniff (PhotoFileSniffer* base,
                                gboolean* is_corrupted,
                                GError** error)
{
	PhotosTiffSniffer * self;
	gboolean _vala_is_corrupted = FALSE;
	DetectedPhotoInformation* result = NULL;
	gboolean _tmp0_ = FALSE;
	GFile* _tmp1_;
	DetectedPhotoInformation* detected = NULL;
	gboolean _tmp2_ = FALSE;
	DetectedPhotoInformation* _tmp3_;
	DetectedPhotoInformation* _tmp4_;
	DetectedPhotoInformation* _tmp5_ = NULL;
	DetectedPhotoInformation* _tmp6_;
	PhotoFileFormat _tmp7_;
	DetectedPhotoInformation* _tmp9_;
	GError * _inner_error_ = NULL;
#line 107 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_SNIFFER, PhotosTiffSniffer);
#line 109 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_vala_is_corrupted = FALSE;
#line 111 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer)->file;
#line 111 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photos_is_tiff (_tmp1_, NULL, &_inner_error_);
#line 111 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 111 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 111 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return NULL;
#line 1376 "TiffSupport.c"
	}
#line 111 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (!_tmp0_) {
#line 112 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		result = NULL;
#line 112 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		if (is_corrupted) {
#line 112 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			*is_corrupted = _vala_is_corrupted;
#line 1386 "TiffSupport.c"
		}
#line 112 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return result;
#line 1390 "TiffSupport.c"
	}
#line 114 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp3_ = PHOTO_FILE_SNIFFER_CLASS (photos_tiff_sniffer_parent_class)->sniff (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_GDK_SNIFFER, GdkSniffer), TYPE_PHOTO_FILE_SNIFFER, PhotoFileSniffer), &_tmp2_, &_inner_error_);
#line 114 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_vala_is_corrupted = _tmp2_;
#line 114 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	detected = _tmp3_;
#line 114 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 114 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 114 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return NULL;
#line 1404 "TiffSupport.c"
	}
#line 115 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp4_ = detected;
#line 115 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (_tmp4_ == NULL) {
#line 116 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		result = NULL;
#line 116 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_detected_photo_information_unref0 (detected);
#line 116 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		if (is_corrupted) {
#line 116 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			*is_corrupted = _vala_is_corrupted;
#line 1418 "TiffSupport.c"
		}
#line 116 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return result;
#line 1422 "TiffSupport.c"
	}
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp6_ = detected;
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp7_ = _tmp6_->file_format;
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (_tmp7_ == PHOTO_FILE_FORMAT_TIFF) {
#line 1430 "TiffSupport.c"
		DetectedPhotoInformation* _tmp8_;
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_tmp8_ = detected;
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_tmp5_ = _tmp8_;
#line 1436 "TiffSupport.c"
	} else {
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_tmp5_ = NULL;
#line 1440 "TiffSupport.c"
	}
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp9_ = _detected_photo_information_ref0 (_tmp5_);
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = _tmp9_;
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_detected_photo_information_unref0 (detected);
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (is_corrupted) {
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		*is_corrupted = _vala_is_corrupted;
#line 1452 "TiffSupport.c"
	}
#line 118 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1456 "TiffSupport.c"
}


static void
photos_tiff_sniffer_class_init (PhotosTiffSnifferClass * klass)
{
#line 102 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_sniffer_parent_class = g_type_class_peek_parent (klass);
#line 102 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileSnifferClass *) klass)->sniff = (DetectedPhotoInformation* (*) (PhotoFileSniffer *, gboolean*, GError**)) photos_tiff_sniffer_real_sniff;
#line 1467 "TiffSupport.c"
}


static void
photos_tiff_sniffer_instance_init (PhotosTiffSniffer * self)
{
}


GType
photos_tiff_sniffer_get_type (void)
{
	static volatile gsize photos_tiff_sniffer_type_id__volatile = 0;
	if (g_once_init_enter (&photos_tiff_sniffer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosTiffSnifferClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_tiff_sniffer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosTiffSniffer), 0, (GInstanceInitFunc) photos_tiff_sniffer_instance_init, NULL };
		GType photos_tiff_sniffer_type_id;
		photos_tiff_sniffer_type_id = g_type_register_static (TYPE_GDK_SNIFFER, "PhotosTiffSniffer", &g_define_type_info, 0);
		g_once_init_leave (&photos_tiff_sniffer_type_id__volatile, photos_tiff_sniffer_type_id);
	}
	return photos_tiff_sniffer_type_id__volatile;
}


PhotosTiffReader*
photos_tiff_reader_construct (GType object_type,
                              const gchar* filepath)
{
	PhotosTiffReader* self = NULL;
#line 123 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 124 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = (PhotosTiffReader*) gdk_reader_construct (object_type, filepath, PHOTO_FILE_FORMAT_TIFF);
#line 123 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self;
#line 1502 "TiffSupport.c"
}


PhotosTiffReader*
photos_tiff_reader_new (const gchar* filepath)
{
#line 123 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return photos_tiff_reader_construct (PHOTOS_TYPE_TIFF_READER, filepath);
#line 1511 "TiffSupport.c"
}


static void
photos_tiff_reader_class_init (PhotosTiffReaderClass * klass)
{
#line 122 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_reader_parent_class = g_type_class_peek_parent (klass);
#line 1520 "TiffSupport.c"
}


static void
photos_tiff_reader_instance_init (PhotosTiffReader * self)
{
}


GType
photos_tiff_reader_get_type (void)
{
	static volatile gsize photos_tiff_reader_type_id__volatile = 0;
	if (g_once_init_enter (&photos_tiff_reader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosTiffReaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_tiff_reader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosTiffReader), 0, (GInstanceInitFunc) photos_tiff_reader_instance_init, NULL };
		GType photos_tiff_reader_type_id;
		photos_tiff_reader_type_id = g_type_register_static (TYPE_GDK_READER, "PhotosTiffReader", &g_define_type_info, 0);
		g_once_init_leave (&photos_tiff_reader_type_id__volatile, photos_tiff_reader_type_id);
	}
	return photos_tiff_reader_type_id__volatile;
}


PhotosTiffWriter*
photos_tiff_writer_construct (GType object_type,
                              const gchar* filepath)
{
	PhotosTiffWriter* self = NULL;
#line 135 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 136 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = (PhotosTiffWriter*) photo_file_writer_construct (object_type, filepath, PHOTO_FILE_FORMAT_TIFF);
#line 135 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self;
#line 1555 "TiffSupport.c"
}


PhotosTiffWriter*
photos_tiff_writer_new (const gchar* filepath)
{
#line 135 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return photos_tiff_writer_construct (PHOTOS_TYPE_TIFF_WRITER, filepath);
#line 1564 "TiffSupport.c"
}


static void
photos_tiff_writer_real_write (PhotoFileWriter* base,
                               GdkPixbuf* pixbuf,
                               JpegQuality quality,
                               GError** error)
{
	PhotosTiffWriter * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 139 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_WRITER, PhotosTiffWriter);
#line 139 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_if_fail (GDK_IS_PIXBUF (pixbuf));
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photo_file_adapter_get_filepath (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = _tmp0_;
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	gdk_pixbuf_save (pixbuf, _tmp1_, "tiff", &_inner_error_, "compression", PHOTOS_TIFF_WRITER_COMPRESSION_LZW, NULL);
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_g_free0 (_tmp1_);
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 140 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return;
#line 1596 "TiffSupport.c"
	}
}


static void
photos_tiff_writer_class_init (PhotosTiffWriterClass * klass)
{
#line 128 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_writer_parent_class = g_type_class_peek_parent (klass);
#line 128 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileWriterClass *) klass)->write = (void (*) (PhotoFileWriter *, GdkPixbuf*, JpegQuality, GError**)) photos_tiff_writer_real_write;
#line 1608 "TiffSupport.c"
}


static void
photos_tiff_writer_instance_init (PhotosTiffWriter * self)
{
}


GType
photos_tiff_writer_get_type (void)
{
	static volatile gsize photos_tiff_writer_type_id__volatile = 0;
	if (g_once_init_enter (&photos_tiff_writer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosTiffWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_tiff_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosTiffWriter), 0, (GInstanceInitFunc) photos_tiff_writer_instance_init, NULL };
		GType photos_tiff_writer_type_id;
		photos_tiff_writer_type_id = g_type_register_static (TYPE_PHOTO_FILE_WRITER, "PhotosTiffWriter", &g_define_type_info, 0);
		g_once_init_leave (&photos_tiff_writer_type_id__volatile, photos_tiff_writer_type_id);
	}
	return photos_tiff_writer_type_id__volatile;
}


PhotosTiffMetadataWriter*
photos_tiff_metadata_writer_construct (GType object_type,
                                       const gchar* filepath)
{
	PhotosTiffMetadataWriter* self = NULL;
#line 145 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (filepath != NULL, NULL);
#line 146 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = (PhotosTiffMetadataWriter*) photo_file_metadata_writer_construct (object_type, filepath, PHOTO_FILE_FORMAT_TIFF);
#line 145 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return self;
#line 1643 "TiffSupport.c"
}


PhotosTiffMetadataWriter*
photos_tiff_metadata_writer_new (const gchar* filepath)
{
#line 145 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return photos_tiff_metadata_writer_construct (PHOTOS_TYPE_TIFF_METADATA_WRITER, filepath);
#line 1652 "TiffSupport.c"
}


static void
photos_tiff_metadata_writer_real_write_metadata (PhotoFileMetadataWriter* base,
                                                 PhotoMetadata* metadata,
                                                 GError** error)
{
	PhotosTiffMetadataWriter * self;
	GFile* _tmp0_;
	GFile* _tmp1_;
	GError * _inner_error_ = NULL;
#line 149 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PHOTOS_TYPE_TIFF_METADATA_WRITER, PhotosTiffMetadataWriter);
#line 149 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_if_fail (IS_PHOTO_METADATA (metadata));
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = photo_file_adapter_get_file (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PHOTO_FILE_ADAPTER, PhotoFileAdapter));
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = _tmp0_;
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photo_metadata_write_to_file (metadata, _tmp1_, &_inner_error_);
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_g_object_unref0 (_tmp1_);
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 150 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return;
#line 1683 "TiffSupport.c"
	}
}


static void
photos_tiff_metadata_writer_class_init (PhotosTiffMetadataWriterClass * klass)
{
#line 144 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	photos_tiff_metadata_writer_parent_class = g_type_class_peek_parent (klass);
#line 144 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	((PhotoFileMetadataWriterClass *) klass)->write_metadata = (void (*) (PhotoFileMetadataWriter *, PhotoMetadata*, GError**)) photos_tiff_metadata_writer_real_write_metadata;
#line 1695 "TiffSupport.c"
}


static void
photos_tiff_metadata_writer_instance_init (PhotosTiffMetadataWriter * self)
{
}


GType
photos_tiff_metadata_writer_get_type (void)
{
	static volatile gsize photos_tiff_metadata_writer_type_id__volatile = 0;
	if (g_once_init_enter (&photos_tiff_metadata_writer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotosTiffMetadataWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photos_tiff_metadata_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotosTiffMetadataWriter), 0, (GInstanceInitFunc) photos_tiff_metadata_writer_instance_init, NULL };
		GType photos_tiff_metadata_writer_type_id;
		photos_tiff_metadata_writer_type_id = g_type_register_static (TYPE_PHOTO_FILE_METADATA_WRITER, "PhotosTiffMetadataWriter", &g_define_type_info, 0);
		g_once_init_leave (&photos_tiff_metadata_writer_type_id__volatile, photos_tiff_metadata_writer_type_id);
	}
	return photos_tiff_metadata_writer_type_id__volatile;
}


gboolean
photos_is_tiff (GFile* file,
                GCancellable* cancellable,
                GError** error)
{
	gboolean result = FALSE;
	GFileInputStream* _tmp0_ = NULL;
	GFileInputStream* _tmp1_;
	GDataInputStream* dins = NULL;
	GDataInputStream* _tmp3_;
	GDataStreamByteOrder order = 0;
	guint16 _tmp4_ = 0U;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp7_;
	GDataStreamByteOrder _tmp8_;
	guint16 lue = 0U;
	GDataInputStream* _tmp9_;
	guint16 _tmp11_;
	GError * _inner_error_ = NULL;
#line 154 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 154 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_return_val_if_fail ((cancellable == NULL) || G_IS_CANCELLABLE (cancellable), FALSE);
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp1_ = g_file_read (file, NULL, &_inner_error_);
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp0_ = _tmp1_;
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1748 "TiffSupport.c"
		gboolean _tmp2_ = FALSE;
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return _tmp2_;
#line 1754 "TiffSupport.c"
	}
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp3_ = g_data_input_stream_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, g_input_stream_get_type (), GInputStream));
#line 155 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	dins = _tmp3_;
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp5_ = dins;
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp4_ = g_data_input_stream_read_uint16 (_tmp5_, cancellable, &_inner_error_);
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1766 "TiffSupport.c"
		gboolean _tmp6_ = FALSE;
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_g_object_unref0 (dins);
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_g_object_unref0 (_tmp0_);
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return _tmp6_;
#line 1776 "TiffSupport.c"
	}
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	switch (_tmp4_) {
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		case 0x4949:
#line 1782 "TiffSupport.c"
		{
#line 161 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			order = G_DATA_STREAM_BYTE_ORDER_LITTLE_ENDIAN;
#line 162 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			break;
#line 1788 "TiffSupport.c"
		}
#line 159 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		case 0x4D4D:
#line 1792 "TiffSupport.c"
		{
#line 165 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			order = G_DATA_STREAM_BYTE_ORDER_BIG_ENDIAN;
#line 166 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			break;
#line 1798 "TiffSupport.c"
		}
		default:
		{
#line 169 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			result = FALSE;
#line 169 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			_g_object_unref0 (dins);
#line 169 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			_g_object_unref0 (_tmp0_);
#line 169 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
			return result;
#line 1810 "TiffSupport.c"
		}
	}
#line 172 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp7_ = dins;
#line 172 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp8_ = order;
#line 172 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	g_data_input_stream_set_byte_order (_tmp7_, _tmp8_);
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp9_ = dins;
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	lue = g_data_input_stream_read_uint16 (_tmp9_, cancellable, &_inner_error_);
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1825 "TiffSupport.c"
		gboolean _tmp10_ = FALSE;
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		g_propagate_error (error, _inner_error_);
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_g_object_unref0 (dins);
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_g_object_unref0 (_tmp0_);
#line 175 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return _tmp10_;
#line 1835 "TiffSupport.c"
	}
#line 176 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_tmp11_ = lue;
#line 176 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	if (((gint) _tmp11_) != 42) {
#line 177 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		result = FALSE;
#line 177 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_g_object_unref0 (dins);
#line 177 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		_g_object_unref0 (_tmp0_);
#line 177 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
		return result;
#line 1849 "TiffSupport.c"
	}
#line 180 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	result = TRUE;
#line 180 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_g_object_unref0 (dins);
#line 180 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	_g_object_unref0 (_tmp0_);
#line 180 "/home/jens/Source/shotwell/src/photos/TiffSupport.vala"
	return result;
#line 1859 "TiffSupport.c"
}



